==> vutil-0.0.1.tar.gz: lib/vutil.dart <==
// You have generated a new plugin project without
// specifying the `--platforms` flag. A plugin project supports no platforms is generated.
// To add platforms, run `flutter create -t plugin --platforms <platforms> .` under the same
// directory. You can also find a detailed instruction on how to add platforms in the `pubspec.yaml` at https://flutter.dev/docs/development/packages-and-plugins/developing-packages#plugin-platforms.

import 'dart:async';

import 'package:flutter/services.dart';

class VUtil {
  static const MethodChannel _channel = const MethodChannel('vutil');

  static Future<String?> get platformVersion async {
    final String? version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  static Future<bool?> setDataToSettings(String key, String value) async {
    assert(key != null);
    final bool? res = await _channel.invokeMethod('setDataToSettings', {'key': key, 'value': value});
    return res;
  }

  static Future<String?> getDataToSettings(String key, String defaultValue) async {
    assert(key != null);
    final String? res = await _channel.invokeMethod('getDataToSettings', {'key': key, 'defaultValue': defaultValue});
    return res;
  }

  static Future<bool?> replaceWord(String ftlDir, String ftlName, String docPath) async {
    final res = await _channel.invokeMethod('replaceWord',{'ftlDir':ftlDir, 'ftlName': ftlName, 'docPath': docPath});
    return res;
  }
  static Future<bool> get isRoot async {
    final bool isRoot = await _channel.invokeMethod('isRoot');
    return isRoot;
  }

  static Future<bool> saveToGallery(String filePath) async {
    final res = await _channel.invokeMethod('saveToGallery',{'filePath':filePath});
    return res;
  }
}

==> vutil-0.0.2.tar.gz: lib/vutil.dart <==
// You have generated a new plugin project without
// specifying the `--platforms` flag. A plugin project supports no platforms is generated.
// To add platforms, run `flutter create -t plugin --platforms <platforms> .` under the same
// directory. You can also find a detailed instruction on how to add platforms in the `pubspec.yaml` at https://flutter.dev/docs/development/packages-and-plugins/developing-packages#plugin-platforms.

import 'dart:async';

import 'package:flutter/services.dart';

class VUtil {
  static const MethodChannel _channel = const MethodChannel('vutil');

  static Future<String?> get platformVersion async {
    final String? version = await _channel.invokeMethod('getPlatformVersion');
    return version;
  }

  static Future<bool?> setDataToSettings(String key, String value) async {
    assert(key != null);
    final bool? res = await _channel.invokeMethod('setDataToSettings', {'key': key, 'value': value});
    return res;
  }

  static Future<String?> getDataToSettings(String key, String defaultValue) async {
    assert(key != null);
    final String? res = await _channel.invokeMethod('getDataToSettings', {'key': key, 'defaultValue': defaultValue});
    return res;
  }

  static Future<bool?> replaceWord(String ftlDir, String ftlName, String docPath) async {
    final res = await _channel.invokeMethod('replaceWord',{'ftlDir':ftlDir, 'ftlName': ftlName, 'docPath': docPath});
    return res;
  }
  static Future<bool> get isRoot async {
    final bool isRoot = await _channel.invokeMethod('isRoot');
    return isRoot;
  }

  /// dir为Environment中的变量，如 Environment.DIRECTORY_DCIM
  static Future<bool> saveToGallery(String filePath, {String? dir}) async {
    final res = await _channel.invokeMethod('saveToGallery',{'filePath':filePath, 'dir': dir});
    return res;
  }
}
